@@ -10,7 +10,7 @@ use warnings;
 use Carp;
 use Device::Modem;
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 our @ISA = ("Device::Modem");
 
 =head1 NAME
@@ -25,15 +25,13 @@ may be imlemented differently, 100% compliance with all dongles is not guarantee
 
 =head1 SYNOPSIS
 
-#! /usr/bin/perl
-
-use Device::Modem::SMSModem;
+ use Device::Modem::SMSModem;
 
  my $modem = new Device::Modem::SMSModem(
      port     => '/dev/ttyUSB0',
      log      => 'file,smstest.log',
      loglevel => 'info');
- 
+  
  if ($modem->connect(baudrate => 38400)) {
      print "Modem connected\n";
  }
@@ -41,33 +39,33 @@ use Device::Modem::SMSModem;
      die "Couldn't connect $!, stopped\n";
  }
 
-# get operator MCC+MNC
-my $op= $modem->get_operator_info();
-print "Operator name: ".$op->{"long_name"}." MCC ".$op->{"mcc"}." MNC:".$op->{"mnc"}."\n";
-# LAC+BTS ID
-my $loc= $modem->get_lac_dec();
-print "LAC: ".$loc->{"lac"}." CELL ID ".$loc->{"cell_id"}."\n";
+ # get operator MCC+MNC
+ my $op= $modem->get_operator_info();
+ print "Operator name: ".$op->{"long_name"}." MCC ".$op->{"mcc"}." MNC:".$op->{"mnc"}."\n";
+ # LAC+BTS ID
+ my $loc= $modem->get_lac_dec();
+ print "LAC: ".$loc->{"lac"}." CELL ID ".$loc->{"cell_id"}."\n";
+ 
+ print "IMSI: ".$modem->get_imsi()."\n";
 
-print "IMSI: ".$modem->get_imsi()."\n";
+ # SMSC addr 
+ print "SMSC address: ".$modem->get_smsc_address()."\n";
 
-# SMSC addr 
-print "SMSC address: ".$modem->get_smsc_address()."\n";
+ print "Setting up SM storage...\n";
+ $modem->init_sms_storage("SM");
 
-print "Setting up SM storage...\n";
-$modem->init_sms_storage("SM");
+ print "Cleaning up storage...\n";
+ $modem->clean_sms_storage();
 
-print "Cleaning up storage...\n";
-$modem->clean_sms_storage();
+ print "Getting number of messages...\n";
 
-print "Getting number of messages...\n";
+ print "Number of messages in the storage: ".$modem->read_sms_count()."\n";
 
-print "Number of messages in the storage: ".$modem->read_sms_count()."\n";
+ print "Looking for new messages...\n";
 
-print "Looking for new messages...\n";
-
-while(1)
-{
-	
+ while(1)
+ {
+ 	
 	my $n= $modem->new_sms_count();
 	if($n)
 	{
@@ -82,8 +80,7 @@ while(1)
 		print "No new messages...\n";		
 	}       	
 	sleep(10);
-}
-
+ }
 
 =head1 DESCRIPTION
 
@@ -92,27 +89,70 @@ API to handle SMS in USB dongles. It works (as base class Device::Modem) via ser
 implements basic SMS functionality handling through AT (Hayes) commands.
 
 =head2 What the module can do
--Get network and registration details
--Get serving SMSC address
--Get IMSI
--Send SMS
--Receive SMS
--Handle SMS storage change
+
+=over 4
+
+=item *
+
+Get network and registration details
+
+=item *
+
+Get serving SMSC address
+
+=item *
+
+Get IMSI
+
+=item *
+
+Send SMS
+
+=item *
+
+Receive SMS
+
+=item *
+
+Handle SMS storage change
+
+=back
+
 
 =head2 What it can be used for
--Simple SMS gateways to send/receive SMS
--SMS notification features
--Just a convenient way to get actual network environment
+
+=over 4
+
+=item *
+
+Simple SMS gateways to send/receive SMS
+
+=item *
+
+SMS notification features
+
+=item *
+
+Just a convenient way to get actual network environment
+
+=back
 
 =head2 Limitations
--At the moment it works through SMS read (AT+CMGR) commands but not through SMS list (AT+CMGL), since I discovered that
+
+=over 4
+
+=item *
+
+At the moment it works through SMS read (AT+CMGR) commands but not through SMS list (AT+CMGL), since I discovered that
 CMGL does not work on my dongle properly. This is not very ideal from SMS handling convenience point of view.
 As soon as I get device with AT+CMGL working it will be  implemented as well
--Some SMS related commands (like setting SMSC address) has not been implemented. If these commands are really 
+
+=item *
+
+Some SMS related commands (like setting SMSC address) has not been implemented. If these commands are really 
 required please drop me a line to contacts below
 
-
-=cut
+=back
 
 =head1 METHODS
 
@@ -305,6 +345,7 @@ sub get_lac_hex {
 }
 
 
+
 =head2 get_lac_dec
 
 =over 4
@@ -366,6 +407,7 @@ sub send_sms {
 }
 
 
+
 =head2 clean_sms_storage
 
 =over 4
